@@ -25,28 +25,27 @@
 ##'
 ##' @param MicrobData Microbiome data matrix containing microbiome abundance with each row per
 ##' sample and each column per taxon/OTU/ASV. It should contain an `"id"` variable to correspond
-##' to the `"id"` variable in the covariates data: `CovData`. This argument can also take file
-##' directory path. For example, `MicrobData="C:\...\microbiomeData.tsv"`.
+##' to the `"id"` variable in the covariates data: `CovData`. This argument can take
+##' directory path. For example, `MicrobData="C://...//microbiomeData.tsv"`.
 ##' @param CovData Covariates data matrix containing covariates and confounders with each row
 ##' per sample and each column per variable. It should also contain an `"id"` variable to
-##' correspond to the `"id"` variable in the microbiome data: `MicrobData`. This argument can also take file
-##' directory path. For example, `CovData = "C:\...\covariatesData.tsv"`.
+##' correspond to the `"id"` variable in the microbiome data: `MicrobData`. This argument can take
+##' directory path. For example, `CovData = "C://...//covariatesData.tsv"`.
 ##' @param linkIDname Variable name of the `"id"` variable in both `MicrobData` and `CovData`. The two data sets will be merged by this `"id"` variable.
 ##' @param testCov Covariates that are of primary interest for testing and estimating the associations. It corresponds to $X_i$ in the equation. Default is `NULL` which means all covariates are `testCov`.
 ##' @param ctrlCov Potential confounders that will be adjusted in the model. It corresponds to $W_i$ in the equation. Default is `NULL` which means all covariates except those in `testCov` are adjusted as confounders.
 ##' @param testMany This takes logical value `TRUE` or `FALSE`. If `TRUE`, the `testCov` will contain all the variables in `CovData` provided `testCov` is set to be `NULL`. The default value is `TRUE` which does not do anything if `testCov` is not `NULL`.
-##' @param ctrlMany This takes logical value `TRUE` or `FALSE`. If `TRUE`, all variables except `testCov` are considered as control covariates provided `ctrlCov` is set to be `NULL`. The default value is `TRUE` which does not do anything if `ctrlCov` is not `NULL`.
+##' @param ctrlMany This takes logical value `TRUE` or `FALSE`. If `TRUE`, all variables except `testCov` are considered as control covariates provided `ctrlCov` is set to be `NULL`. The default value is `FALSE`.
 ##' @param nRef The number of randomly picked reference taxa used in phase 1. Default number is `40`.
 ##' @param nPermu The number of permutation used in phase 1. Default number is `40`.
-##' @param x1permut This takes a logical value `TRUE` or `FALSE`. If true, it will permute the variables in testCov. If false, it will use residual-permutation proposed by Freedman and Lane (1983).
+##' @param x1permut This takes a logical value `TRUE` or `FALSE`. If true, it will permute the variables in testCov. If false, it will use residual-permutation proposed by Freedman and Lane (1983). Default is 'TRUE'.
 ##' @param refTaxa A vector of taxa or OTU or ASV names. These are reference taxa specified by the user to be used in phase 1. If the number of reference taxa is less than 'nRef', the algorithm will randomly pick extra reference taxa to make up 'nRef'. The default is `NULL` since the algorithm will pick reference taxa randomly.
 ##' @param reguMethod regularization approach used in phase 1 of the algorithm. Default is `"mcp"`. Other methods are under development.
 ##' @param fwerRate The family wise error rate for identifying taxa/OTU/ASV associated with `testCov` in phase 1. Default is `0.25`.
-##' @param sequentialRun This takes a logical value `TRUE` or `FALSE`. Sometimes parallel jobs can not be successfully run for unknown reasons. For example, socket related errors may pop up or some slave cores return simple error instead of numerical results. In those scenarios, setting `sequentialRun = TRUE` may help, but it will take more time to run. Default is `FALSE`.
-##' @param paraJobs If `sequentialRun` is `FALSE`, this specifies the number of parallel jobs that will be registered to run the algorithm. Default is `8`. If specified as `NULL`, it will automatically detect the cores to decide the number of parallel jobs.
+##' @param sequentialRun This takes a logical value `TRUE` or `FALSE`. Default is `FALSE`. This argument could be useful for debug.
+##' @param paraJobs If `sequentialRun` is `FALSE`, this specifies the number of parallel jobs that will be registered to run the algorithm. If specified as `NULL`, it will automatically detect the cores to decide the number of parallel jobs. Default is `NULL`. It is safe to have 4gb memory per job. It may be needed to reduce the number of jobs if memory is limited.
 ##' @param standardize This takes a logical value `TRUE` or `FALSE`. If `TRUE`, all design matrix X in phase 1 and phase 2 will be standardized in the analyses. Default is `FALSE`.
 ##' @param nRefMaxForEsti The maximum number of reference taxa used in phase 2. The default is `1`.
-##' @param allFunc all the user-defined function names that will be passed to the parallel computing environment (foreach loop).
 ##' @param bootB Number of bootstrap samples for obtaining confidence interval of estimates in phase 2. The default is `500`.
 ##' @param bootLassoAlpha The significance level in phase 2. Default is `0.05`.
 ##' @param refReadsThresh The threshold of non-zero sequencing reads for choosing the reference taxon in phase 2. The default is `0.2` which means at least 20% non-zero sequencing reads.
@@ -72,13 +71,17 @@
 ##'                 CovData = dataC,
 ##'                 linkIDname = "id",
 ##'                 testCov = c("v1", "v2"),
-##'                 ctrlCov = c("v3"), nRef = 4,
-##'                 nPermu = 4,
+##'                 ctrlCov = c("v3"), nRef = 3,
+##'                 nPermu = 3,
+##'                 paraJobs = 2,
 ##'                 fwerRate = 0.25,
 ##'                 bootB = 5)
+##'
 ##'}
 ##'
-##' @references Li et al.(2020) IFAA: Robust association identification and Inference For Absolute Abundance in microbiome analyses. arXiv:1909.10101v3
+##'
+##'
+##' @references Li et al.(In press) IFAA: Robust association identification and Inference For Absolute Abundance in microbiome analyses. Journal of the American Statistical Association
 ##' @references Zhang CH (2010) Nearly unbiased variable selection under minimax concave penalty. Annals of Statistics. 38(2):894-942.
 ##' @references Freedman and Lane (1983) A non-stochastic interpretation of reported significance levels. Journal of Business & Economic Statistics. 1(4):292-298.
 
@@ -90,6 +93,7 @@
 ##' @importFrom Matrix Diagonal Matrix
 ##' @importFrom HDCI bootLOPR
 ##' @importFrom picasso picasso
+##' @importFrom qlcMatrix corSparse
 ##' @import mathjaxr
 ##' @export
 ##' @md
@@ -97,7 +101,6 @@
 
 
 
-
 IFAA=function(
   MicrobData,
   CovData,
@@ -118,13 +121,14 @@ IFAA=function(
   bootLassoAlpha=0.05,
   standardize=FALSE,
   sequentialRun=FALSE,
-  allFunc=allUserFunc(),
   refReadsThresh=0.2,
   SDThresh=0.05,
   SDquantilThresh=0,
   balanceCut=0.2,
   seed=1
 ){
+  allFunc=allUserFunc()
+
   results=list()
   start.time = proc.time()[3]
   runMeta=metaData(MicrobData=MicrobData,CovData=CovData,
@@ -202,7 +206,7 @@ IFAA=function(
   rm(testCovInOrder,ctrlCov,microbName)
 
   totalTimeMins = (proc.time()[3] - start.time)/60
-  message("The entire analysis took",totalTimeMins, "minutes","\n")
+  message("The entire analysis took ",round(totalTimeMins,2), " minutes")
 
   results$totalTimeMins=totalTimeMins
 
